Methodology
----------------------

Microservice Architecture
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

``piel`` is designed to be a microservice architecture. This means that
each tool is a separate service that can be run independently. This is a
very powerful design pattern that allows for the development of each
tool independently. It also allows for the development of new tools that
can be integrated into the ``piel`` framework without having to change
the existing tools.
